"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseRepository = void 0;
class BaseRepository {
    constructor(model) {
        this.model = model;
        this.findOne = async (filter = {}) => {
            return await this.model.findOne({
                where: filter.where,
                include: filter.include || undefined,
            });
        };
        this.findAll = async (filter = {}) => {
            const entities = await this.model.findAll({
                where: filter.where || undefined,
                include: filter.include || undefined,
            });
            return entities;
        };
        this.create = async (data, includeModels = [], transaction) => {
            return await this.model.create(data, {
                include: includeModels,
                transaction,
            });
        };
        this.bulkCreate = async (data, includeModels = []) => {
            return await this.model.bulkCreate(data, {
                include: includeModels,
            });
        };
        this.update = async (id, data) => {
            Object.keys(data).forEach((key) => {
                const typedKey = key;
                if (data[typedKey] === undefined) {
                    data[typedKey] = null;
                }
            });
            await this.model.update(data, {
                where: { id },
            });
        };
        this.delete = async (ids) => {
            await this.model.destroy({
                where: { id: ids },
            });
        };
        this.paginate = async (page = 1, limit = 10, filter = {}) => {
            const { count: total, rows: data } = await this.model.findAndCountAll({
                where: filter.where || undefined,
                include: filter.include || undefined,
                offset: (page - 1) * limit,
                limit,
                order: filter.order,
                distinct: true,
            });
            return {
                data,
                total,
                page,
                limit,
            };
        };
    }
}
exports.BaseRepository = BaseRepository;
